@@ -2,7 +2,7 @@
 
 __description__ = "Windows Shortcut file (LNK) parser"
 __author__ = "Matmaus"
-__version__ = "1.1.0"
+__version__ = "1.1.1"
 
 import json
 import datetime
@@ -135,12 +135,9 @@ class LnkFile(object):
             cprint("Size: %s" % self.targets.id_list_size(), 2)
             cprint("Index: %s" % self._target_index, 2)
             cprint("ITEMS:", 2)
-            for target in self.targets:
-                target_item = target.as_item()
-                if target_item is None:
-                    continue
-                cprint(target_item["class"], 3)
-                for key, value in target_item.items():
+            for target in self.targets.as_list():
+                cprint(target["class"], 3)
+                for key, value in target.items():
                     if key != "class":
                         cprint(f"{nice_id(key)}: {value}", 4)
             cprint("")
